@@ -1,7 +1,7 @@
 import logging
 import os
 from pathlib import Path
-from typing import List, Union, Tuple
+from typing import List, Union, Tuple, Optional
 
 import numpy as np
 import pyproj
@@ -21,8 +21,8 @@ logger = logging.getLogger(__name__)
 class Campaign:
     def __init__(self, name="", folder: Union[list, str] = None, recursive=True, exclude: Union[list, str] = None,
                  sync_method: str = None, strip_timezone: bool = True, cutoff: bool = True, lat_sw: float = None,
-                 lon_sw: float = None, lat_ne: float = None,
-                 lon_ne: float = None, download_osm_region: bool = False, filter_osm_region: bool = False,
+                 lon_sw: float = None, lat_ne: float = None, lon_ne: float = None,
+                 download_osm_region: bool = False, filter_osm_region: bool = False, osm_recurse_type: str = ">",
                  railway_types: Union[list, str] = None):
         """
 
@@ -59,7 +59,10 @@ class Campaign:
             If True removes railway elements that are not close to the GPS Tracks of the campaign
         railway_types: list or list of str
             Railway type to be downloaded from OSM, e.g., "rail", "subway", "tram" or "light_rail"
+        osm_recurse_type : str
+            Recurse type to be used when querying OSM data using the overpass API
         """
+
         self._colors = []  # Used colors
 
         self.folder = folder
@@ -67,7 +70,9 @@ class Campaign:
         self.files: List[RDYFile] = []
         self.lat_sw, self.lon_sw = lat_sw, lon_sw
         self.lat_ne, self.lon_ne = lat_ne, lon_ne
+
         self.osm_region = None
+        self.osm_recurse_type = osm_recurse_type
 
         if sync_method is not None and sync_method not in ["timestamp", "device_time", "gps_time", "ntp_time"]:
             raise ValueError(
@@ -85,7 +90,7 @@ class Campaign:
 
         if download_osm_region:
             self.osm_region = OSMRegion(lat_sw=self.lat_sw, lon_sw=self.lon_sw, lat_ne=self.lat_ne, lon_ne=self.lon_ne,
-                                        desired_railway_types=railway_types)
+                                        desired_railway_types=railway_types, recurse=self.osm_recurse_type)
             if filter_osm_region:
                 self.filter_osm_region()
 
@@ -379,7 +384,8 @@ class Campaign:
 
     def import_files(self, paths: Union[list, str] = None, sync_method: str = None,
                      det_geo_extent: bool = True, download_osm_region: bool = False,
-                     filter_osm_region: bool = False, railway_types: Union[list, str] = None):
+                     filter_osm_region: bool = False, railway_types: Union[list, str] = None,
+                     osm_recurse_type: Optional[str] = None):
         """ Import files into the campaign
 
         Parameters
@@ -396,7 +402,12 @@ class Campaign:
             If True, removes railway elements that are not close to the GPS tracks
         railway_types: str or list of str
             Railway types to be downloaded via the Overpass API
+        osm_recurse_type : str
+            Recurse type to be used when querying OSM data using the overpass API
         """
+        if osm_recurse_type:
+            self.osm_recurse_type = osm_recurse_type
+
         if type(paths) == str:
             paths = [paths]
         elif type(paths) == list:
@@ -416,7 +427,7 @@ class Campaign:
 
         if download_osm_region:
             self.osm_region = OSMRegion(lat_sw=self.lat_sw, lon_sw=self.lon_sw, lat_ne=self.lat_ne, lon_ne=self.lon_ne,
-                                        desired_railway_types=railway_types)
+                                        desired_railway_types=railway_types, recurse=self.osm_recurse_type)
             if filter_osm_region:
                 self.filter_osm_region()
 
@@ -424,7 +435,8 @@ class Campaign:
                       sync_method: str = None, strip_timezone: bool = None, cutoff: bool = True,
                       det_geo_extent: bool = True, download_osm_region: bool = False,
                       filter_osm_region: bool = False,
-                      railway_types: Union[list, str] = None):
+                      railway_types: Union[list, str] = None,
+                      osm_recurse_type: Optional[str] = None):
         """ Imports folder(s) into the campaign
 
         Parameters
@@ -449,7 +461,12 @@ class Campaign:
             If True, removes railway elements that are not close to the GPS tracks
         railway_types: str or list of str
             Railway types to be downloaded via the Overpass API
+        osm_recurse_type : str
+            Recurse type to be used when querying OSM data using the overpass API
         """
+        if osm_recurse_type:
+            self.osm_recurse_type = osm_recurse_type
+
         if exclude is None:
             exclude = []
         elif type(exclude) == str:
@@ -510,6 +527,6 @@ class Campaign:
 
         if download_osm_region:
             self.osm_region = OSMRegion(lat_sw=self.lat_sw, lon_sw=self.lon_sw, lat_ne=self.lat_ne, lon_ne=self.lon_ne,
-                                        desired_railway_types=railway_types)
+                                        desired_railway_types=railway_types, recurse=self.osm_recurse_type)
             if filter_osm_region:
                 self.filter_osm_region()
